==> coil-0.13.0-javadoc.jar: coil-base/coil.transition/-transition-target/index.md <==
[coil-base](../../index.md) / [coil.transition](../index.md) / [TransitionTarget](./index.md)

# TransitionTarget

`@ExperimentalCoilApi interface TransitionTarget : `[`Target`](../../coil.target/-target/index.md)

A [Target](../../coil.target/-target/index.md) that supports applying [Transition](../-transition/index.md)s.

### Properties

| Name | Summary |
|---|---|
| [drawable](drawable.md) | The [view](view.md)'s current [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html).`abstract val drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?` |
| [view](view.md) | The [View](https://developer.android.com/reference/android/view/View.html) used by this [Target](../../coil.target/-target/index.md).`abstract val view: `[`View`](https://developer.android.com/reference/android/view/View.html) |

### Inheritors

| Name | Summary |
|---|---|
| [ImageViewTarget](../../coil.target/-image-view-target/index.md) | A [Target](../../coil.target/-target/index.md) that handles setting images on an [ImageView](https://developer.android.com/reference/android/widget/ImageView.html).`open class ImageViewTarget : `[`PoolableViewTarget`](../../coil.target/-poolable-view-target/index.md)`<`[`ImageView`](https://developer.android.com/reference/android/widget/ImageView.html)`>, `[`TransitionTarget`](./index.md)`, `[`DefaultLifecycleObserver`](https://developer.android.com/reference/androidx/androidx/lifecycle/DefaultLifecycleObserver.html) |

==> coil-1.0.0-rc3-javadoc.jar: coil-base/coil.transition/-transition-target/index.md <==
[coil-base](../../index.md) / [coil.transition](../index.md) / [TransitionTarget](./index.md)

# TransitionTarget

`@ExperimentalCoilApi interface TransitionTarget : `[`Target`](../../coil.target/-target/index.md)

A [Target](../../coil.target/-target/index.md) that supports applying [Transition](../-transition/index.md)s.

### Properties

| Name | Summary |
|---|---|
| [drawable](drawable.md) | The [view](view.md)'s current [Drawable](https://developer.android.com/reference/android/graphics/drawable/Drawable.html).`abstract val drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?` |
| [view](view.md) | The [View](https://developer.android.com/reference/android/view/View.html) used by this [Target](../../coil.target/-target/index.md).`abstract val view: `[`View`](https://developer.android.com/reference/android/view/View.html) |

### Inheritors

| Name | Summary |
|---|---|
| [ImageViewTarget](../../coil.target/-image-view-target/index.md) | A [Target](../../coil.target/-target/index.md) that handles setting images on an [ImageView](https://developer.android.com/reference/android/widget/ImageView.html).`open class ImageViewTarget : `[`PoolableViewTarget`](../../coil.target/-poolable-view-target/index.md)`<`[`ImageView`](https://developer.android.com/reference/android/widget/ImageView.html)`>, `[`TransitionTarget`](./index.md)`, `[`DefaultLifecycleObserver`](https://developer.android.com/reference/androidx/lifecycle/DefaultLifecycleObserver.html) |
